pub trait DefaultBackendBuilder {
type Backend: Backend<Self>;
// Required method
fn build_backend() -> Self::Backend;
}Expand description
Allows to specify a default backend for some type
Example
use interns::DefaultBackendBuilder;
/* Get the default backend for the str type */
let backend = <str as DefaultBackendBuilder>::build_backend();Required Associated Types
Required Methods
fn build_backend() -> Self::Backend
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.